@@ -226,6 +226,37 @@ function rmDirectory($dirname)
 	}
 	return $ret;
 }
+/**
+ * ファイルへのデータの書き込み
+ *
+ * @param string $path				書き込み先ファイルフルパス
+ * @param string $data				書き込みデータ
+ * @param bool $mkDirectory			ファイルまでのディレクトリを作成するかどうか
+ * @return bool						true=削除完了、false=削除失敗
+ */
+function writeFile($path, $data, $mkDirectory = true)
+{
+	$ret = false;		// 戻り値リセット
+	
+	// ディレクトリ作成
+	$dirPath = dirname($path);
+	if (!file_exists($dirPath)){// ディレクトリがないとき
+		if (!mkdir($dirPath, 0770, true/*再帰的*/)) return false;
+	}
+	
+	$fp = fopen($path, "w+");
+	if ($fp){
+		if (flock($fp, LOCK_EX)) { // 排他ロック
+			fwrite($fp, $data);
+			flock($fp, LOCK_UN); // ロックを解放
+			$ret = true;
+		}
+		fclose($fp);
+		return $ret;
+	} else {
+		return $ret;
+	}
+}
 /**
  * ユーザカスタマイズ用パラメータの解析
  *
