@@ -1670,14 +1670,14 @@ class SystemDb extends BaseDb
 	 * @param string    $typeId				コンテンツタイプ
 	 * @param int     	$serial				シリアル番号
 	 * @param string	$day				日にち
-	 * @param int		$hour				時間
+	 * @param int		$hour				時間(0～23)
 	 * @return bool							true=成功, false=失敗
 	 */
-	function updateViewCount($typeId, $serial, $day, $hour)
+	function updateViewCount($typeId, $serial, $day = null, $hour = null)
 	{
 		// 現在日時を取得
-		if (empty($day)) $day = date("Y/m/d");		// 日
-		if (empty($hour)) $hour = (int)date("H");		// 時間
+		if (is_null($day)) $day = date("Y/m/d");		// 日
+		if (is_null($hour)) $hour = (int)date("H");		// 時間
 		
 		// トランザクション開始
 		$this->startTransaction();
@@ -1707,6 +1707,36 @@ class SystemDb extends BaseDb
 		$ret = $this->endTransaction();
 		return $ret;
 	}
+	/**
+	 * コンテンツのビューカウント総数を取得
+	 *
+	 * @param string    $typeId				コンテンツタイプ
+	 * @param int     	$serial				シリアル番号
+	 * @param timestamp	$startDt			期間(開始日)
+	 * @param timestamp	$endDt				期間(終了日)
+	 * @return int							総数
+	 */
+	function getTotalViewCount($typeId, $serial, $startDt = null, $endDt = null)
+	{
+		$params = array();
+		$queryStr  = 'SELECT SUM(vc_count) AS total FROM _view_count ';
+		$queryStr .=   'WHERE vc_type_id = ? ';	$params[] = $typeId;		// データタイプはデフォルトコンテンツ
+		$queryStr .=     'AND vc_content_serial = ? '; $params[] = $serial;
+
+		// 日付範囲
+		if (!empty($startDt)){
+			$queryStr .=    'AND ? <= vc_date ';
+			$params[] = $startDt;
+		}
+		if (!empty($endDt)){
+			$queryStr .=    'AND vc_date < ? ';
+			$params[] = $endDt;
+		}
+		$count = 0;
+		$ret = $this->selectRecord($queryStr, $params, $row);
+		if ($ret) $count = intval($row['total']);
+		return $count;
+	}
 	/**
 	 * エラーログ書き込み
 	 *
