@@ -1,6 +1,6 @@
 <?php
 /**
- * メールマネージャー
+ * アクセス解析マネージャー
  *
  * PHP versions 5
  *
@@ -8,7 +8,7 @@
  *
  * @package    Magic3 Framework
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
- * @copyright  Copyright 2006-2007 Magic3 Project.
+ * @copyright  Copyright 2006-2008 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
  * @version    SVN: $Id$
  * @link       http://www.magic3.org
@@ -41,5 +41,17 @@ class AnalyzeManager
 		$ret = $this->db->updateViewCount($typeId, $serial, $day, $hour);
 		return $ret;
 	}
+	/**
+	 * コンテンツのビューカウントを取得
+	 *
+	 * @param string    $typeId				コンテンツタイプ
+	 * @param int     	$serial				コンテンツシリアル番号
+	 * @return int							総参照数
+	 */
+	function getTotalContentViewCount($typeId, $serial)
+	{
+		$count = $this->db->getTotalViewCount($typeId, $serial);
+		return $count;
+	}
 }
 ?>
