@@ -39,16 +39,16 @@ class PageManager
 	private $useScriptaculous;			// scriptaculousを使用するかどうか
 	private $headDescription;				// HTMLヘッダ「description」に出力する文字列
 	private $headKeywords;				// HTMLヘッダ「keywords」に出力する文字列
+	private $headCss = array();					// HTMLヘッダにCSS出力する文字列
 	private $outputHead;				// HTMLヘッダ出力を行ったかどうか
-	//private $libJqueryEasing;			// jquery.easing用のファイル
-	//private $libJqueryJcarousel;			// jquery.jcarousel用のファイル
 	private $libFiles;					// javascript追加用ライブラリ
 	const ADMIN_WIDGET_ID = 'admin_main';		// 管理用ウィジェットのウィジェットID
 	const WIDGET_ID_TAG_START = '{{WIDGETID:';		// 遅延実行用タグ
 	const WIDGET_ID_TAG_END = '}}';		// 遅延実行用タグ
 	const WIDGET_ID_SEPARATOR = ',';
-	const HEAD_TAG_KEYWORDS = 		'{{HEAD_KEYWORDS}}';			// HTMLヘッダのkeywords埋め込み用タグ
-	const HEAD_TAG_DESCRIPTION = 	'{{HEAD_DESCRIPTION}}';			// HTMLヘッダのdescription埋め込み用タグ
+	const HEAD_TAG_KEYWORDS		= 	'{{HEAD_KEYWORDS}}';			// HTMLヘッダのkeywords埋め込み用タグ
+	const HEAD_TAG_DESCRIPTION	= 	'{{HEAD_DESCRIPTION}}';			// HTMLヘッダのdescription埋め込み用タグ
+	const HEAD_TAG_CSS			= 	'{{HEAD_CSS}}';			// HTMLヘッダのCSS埋め込み用タグ
 	const WIDGET_ICON_IMG_SIZE = 32;			// ウィジェットアイコンサイズ
 	const POSITION_TAG_HEAD = 'm3pos_';			// ポジションの識別用タグIDヘッダ
 	const WIDGET_TAG_HEAD = 'm3widget_';			// ウィジェットの識別用タグIDヘッダ
@@ -149,6 +149,16 @@ class PageManager
 	{
 		$this->headKeywords = $str;
 	}
+	/**
+	 * HTMLヘッダに出力するCSSの文字列を設定
+	 *
+	 * @param string $css	追加するCSS内容
+	 * @return 				なし
+	 */
+	function addHeadCss($css)
+	{
+		$this->headCss[] = $css;
+	}
 	/**
 	 * 表示ポジションを表示するかどうか
 	 *
@@ -445,6 +455,19 @@ class PageManager
 				$replaceStr = '<meta name="keywords" content="' . htmlspecialchars($this->headKeywords) . '" />' . M3_NL;
 				$destBuf = str_replace(self::HEAD_TAG_KEYWORDS, $replaceStr, $destBuf);
 			}
+			// HEADタグに埋め込むCSS
+			if (count($this->headCss) > 0){
+				$replaceStr = '<style type="text/css">' . M3_NL;
+				$replaceStr .= '<!--' . M3_NL;
+				for ($i = 0; $i < count($this->headCss); $i++){
+					$replaceStr .= $this->headCss[$i];
+				}
+				$replaceStr .= '//-->' . M3_NL;
+				$replaceStr .= '</style>' . M3_NL;
+				$destBuf = str_replace(self::HEAD_TAG_CSS, $replaceStr, $destBuf);
+			} else {// 空のときはタグを消去
+				$destBuf = str_replace(self::HEAD_TAG_CSS, '', $destBuf);
+			}
 		}
 		return $destBuf;
 	}
@@ -993,8 +1016,8 @@ class PageManager
 		// ##### タグ変換用のタグを埋め込む #####
 		// ウィジェット単体実行のときはタグを埋め込まない
 		if (!$this->showWidget){
-			echo self::HEAD_TAG_KEYWORDS;			// HTMLヘッダのkeywords埋め込み用タグ
-			echo self::HEAD_TAG_DESCRIPTION;			// HTMLヘッダのdescription埋め込み用タグ
+			echo self::HEAD_TAG_KEYWORDS;		// HTMLヘッダのkeywords埋め込み用タグ
+			echo self::HEAD_TAG_DESCRIPTION;	// HTMLヘッダのdescription埋め込み用タグ
 		}
 		// 検索ロボットへの指示
 		$robots = htmlspecialchars(trim($this->db->getSiteDefValue(M3_TB_FIELD_SITE_ROBOTS)));
@@ -1026,6 +1049,11 @@ class PageManager
 		if (!empty($title)){
 			echo '<title>' . $title . '</title>' . M3_NL;
 		}
+		// ##### タグ変換用のタグを埋め込む #####
+		// HTMLヘッダのCSS埋め込み用タグ
+		if (!$this->showWidget){		// ウィジェット単体実行のときはタグを埋め込まない
+			echo self::HEAD_TAG_CSS;			
+		}
 		// JavaScriptグローバル変数の設定
 		echo '<script type="text/javascript">' . M3_NL;
 		echo '<!--' . M3_NL;
