@@ -860,24 +860,34 @@ CREATE TABLE order_detail (
     UNIQUE               (od_order_id,  od_index,      od_history_index)
 ) TYPE=innodb;
 
--- 在庫管理トラン
-DROP TABLE IF EXISTS stock;
-CREATE TABLE stock (
-    st_serial            INT            AUTO_INCREMENT,                              -- レコードシリアル番号
-    st_product_id        INT            DEFAULT 0                     NOT NULL,      -- 商品ID
-    st_history_index     INT            DEFAULT 0                     NOT NULL,      -- 履歴管理用インデックスNo(0～)
+-- 商品記録トラン
+DROP TABLE IF EXISTS product_record;
+CREATE TABLE product_record (
+    pe_serial            INT            AUTO_INCREMENT,                              -- レコードシリアル番号
+    pe_product_id        INT            DEFAULT 0                     NOT NULL,      -- 商品ID
+    pe_language_id       VARCHAR(2)     DEFAULT ''                    NOT NULL,      -- 言語ID
+    
+    pe_order_count       INT            DEFAULT 0                     NOT NULL,      -- 累積注文数
+    pe_sales_count       INT            DEFAULT 0                     NOT NULL,      -- 累積販売数
+    pe_stock_count       INT            DEFAULT 0                     NOT NULL,      -- 表示在庫数
+    pe_view_count        INT            DEFAULT 0                     NOT NULL,      -- 参照回数
+    pe_promote_count     INT            DEFAULT 0                     NOT NULL,      -- 販売促進回数
+    
+    pe_update_user_id    INT            DEFAULT 0                     NOT NULL,      -- レコード更新者
+    pe_update_dt         TIMESTAMP      DEFAULT '0000-00-00 00:00:00' NOT NULL,      -- レコード更新日時
+    PRIMARY KEY          (pe_serial),
+    UNIQUE               (pe_product_id,        pe_language_id)
+) TYPE=innodb;
 
-    st_view_quantity     INT            DEFAULT 0                     NOT NULL,      -- 表示在庫数
-    st_quantity          INT            DEFAULT 0                     NOT NULL,      -- 在庫数
-    st_assigned_quantity INT            DEFAULT 0                     NOT NULL,      -- 引当数
-
-    st_create_user_id    INT            DEFAULT 0                     NOT NULL,      -- レコード作成者
-    st_create_dt         TIMESTAMP      DEFAULT '0000-00-00 00:00:00' NOT NULL,      -- レコード作成日時
-    st_update_user_id    INT            DEFAULT 0                     NOT NULL,      -- レコード更新者
-    st_update_dt         TIMESTAMP      DEFAULT '0000-00-00 00:00:00' NOT NULL,      -- レコード更新日時
-    st_deleted           BOOLEAN        DEFAULT false                 NOT NULL,      -- レコード削除状態
-    PRIMARY KEY          (st_serial),
-    UNIQUE               (st_product_id,        st_history_index)
+-- 商品参照ログ
+DROP TABLE IF EXISTS product_view;
+CREATE TABLE product_view (
+    pv_serial            INT            AUTO_INCREMENT,                              -- レコードシリアル番号
+    pv_type              INT            DEFAULT 0                     NOT NULL,      -- ログタイプ(0=表示)
+    pv_product_serial    INT            DEFAULT 0                     NOT NULL,      -- 商品項目シリアル番号
+    pv_log_serial        INT            DEFAULT 0                     NOT NULL,      -- アクセスログシリアル番号
+    pv_dt                TIMESTAMP      DEFAULT '0000-00-00 00:00:00' NOT NULL,      -- 参照日時
+    PRIMARY KEY          (pv_serial)
 ) TYPE=innodb;
 
 -- 入出庫予定トラン
