@@ -140,6 +140,14 @@ CREATE TABLE blog_config (
     bg_index             INT            DEFAULT 0                     NOT NULL,      -- ソート用
     PRIMARY KEY          (bg_id)
 ) TYPE=innodb;
+INSERT INTO blog_config (bg_id,              bg_value,    bg_name,                     bg_index)
+VALUES                 ('receive_comment',   '0',         'コメントを受け付け',        1);
+INSERT INTO blog_config (bg_id,              bg_value,    bg_name,                     bg_index)
+VALUES                 ('receive_trackback', '0',         'トラックバックの受け付け',  2);
+INSERT INTO blog_config (bg_id,              bg_value,    bg_name,                     bg_index)
+VALUES                 ('entry_view_count',  '10',        '記事表示数',                3);
+INSERT INTO blog_config (bg_id,              bg_value,    bg_name,                     bg_index)
+VALUES                 ('entry_view_order',  '1',        '記事表示順',                 4);
 
 -- ブログカテゴリマスター
 DROP TABLE IF EXISTS blog_category;
@@ -173,10 +181,14 @@ CREATE TABLE blog_entry (
     
     be_name              VARCHAR(40)    DEFAULT ''                    NOT NULL,      -- エントリータイトル
     be_html              VARCHAR(2000)  DEFAULT ''                    NOT NULL,      -- エントリー本文HTML
+    be_html_ext          VARCHAR(2000)  DEFAULT ''                    NOT NULL,      -- エントリー本文HTML(続き)
+    be_description       VARCHAR(100)   DEFAULT ''                    NOT NULL,      -- 概要
     be_status            SMALLINT       DEFAULT 0                     NOT NULL,      -- エントリー状態(0=未設定、1=編集中、2=公開、3=非公開)
-    be_category          TEXT           DEFAULT ''                    NOT NULL,      -- エントリー所属カテゴリー(「,」区切りで複数指定可)
+    be_search_tag        VARCHAR(100)   DEFAULT ''                    NOT NULL,      -- 検索用タグ(「,」区切り)
     be_regist_user_id    INT            DEFAULT 0                     NOT NULL,      -- エントリー作者
     be_regist_dt         TIMESTAMP      DEFAULT '0000-00-00 00:00:00' NOT NULL,      -- 投稿日時
+    be_active_start_dt   TIMESTAMP      DEFAULT '0000-00-00 00:00:00' NOT NULL,      -- 公開期間(開始)
+    be_active_end_dt     TIMESTAMP      DEFAULT '0000-00-00 00:00:00' NOT NULL,      -- 公開期間(終了)
 
     be_check_out_user_id INT            DEFAULT 0                     NOT NULL,      -- チェックアウトユーザID(0のときはチェックイン状態)
     be_check_out_dt      TIMESTAMP      DEFAULT '0000-00-00 00:00:00' NOT NULL,      -- チェックアウト日時
@@ -189,6 +201,40 @@ CREATE TABLE blog_entry (
     UNIQUE               (be_id,        be_language_id,               be_history_index)
 ) TYPE=innodb;
 
+-- ブログ記事とブログ記事カテゴリーの対応付けマスター
+DROP TABLE IF EXISTS blog_entry_with_category;
+CREATE TABLE blog_entry_with_category (
+    bw_serial            INT            AUTO_INCREMENT,                              -- レコードシリアル番号
+    bw_entry_id          INT            DEFAULT 0                     NOT NULL,      -- ブログ記事ID
+    bw_language_id       VARCHAR(2)     DEFAULT ''                    NOT NULL,      -- 言語ID
+    bw_history_index     INT            DEFAULT 0                     NOT NULL,      -- 履歴管理用インデックスNo(0～)
+    bw_index             INT            DEFAULT 0                     NOT NULL,      -- インデックス番号
+    bw_category_id       INT            DEFAULT 0                     NOT NULL,      -- ブログ記事カテゴリーID
+    bw_deleted           BOOLEAN        DEFAULT false                 NOT NULL,      -- レコード削除状態
+    PRIMARY KEY          (bw_serial),
+    UNIQUE               (bw_entry_id,        bw_language_id,       bw_history_index,     bw_index)
+) TYPE=innodb;
+
+-- ブログコメントトラン
+DROP TABLE IF EXISTS blog_comment;
+CREATE TABLE blog_comment (
+    bo_serial            INT            AUTO_INCREMENT,                              -- レコードシリアル番号
+    bo_entry_id          INT            DEFAULT 0                     NOT NULL,      -- エントリーID
+    bo_user_id           INT            DEFAULT 0                     NOT NULL,      -- ユーザID
+    bo_regist_dt         TIMESTAMP      DEFAULT '0000-00-00 00:00:00' NOT NULL,      -- 投稿日時
+    
+    bo_title             VARCHAR(50)    DEFAULT ''                    NOT NULL,      -- タイトル
+    bo_html              VARCHAR(200)   DEFAULT ''                    NOT NULL,      -- 本文HTML
+    bo_url               TEXT           DEFAULT ''                    NOT NULL,      -- 参照用URL
+    bo_user_name         VARCHAR(40)    DEFAULT ''                    NOT NULL,      -- ユーザ名
+    bo_email             VARCHAR(40)    DEFAULT ''                    NOT NULL,      -- Eメールアドレス
+    
+    bo_update_user_id    INT            DEFAULT 0                     NOT NULL,      -- レコード更新者
+    bo_update_dt         TIMESTAMP      DEFAULT '0000-00-00 00:00:00' NOT NULL,      -- レコード更新日時
+    bo_deleted           BOOLEAN        DEFAULT false                 NOT NULL,      -- レコード削除状態
+    PRIMARY KEY          (bo_serial)
+) TYPE=innodb;
+
 -- BBS設定マスター
 DROP TABLE IF EXISTS bbs_config;
 CREATE TABLE bbs_config (
