@@ -17,7 +17,7 @@ require_once($gEnvManager->getContainerPath() . '/baseWidgetContainer.php');
 
 class _installCompleteWidgetContainer extends BaseWidgetContainer
 {
-	var $db;	// DB接続オブジェクト
+	private $db;	// DB接続オブジェクト
 
 	/**
 	 * コンストラクタ
