@@ -78,12 +78,13 @@ class admin_mainConfigsiteWidgetContainer extends BaseWidgetContainer
 			$licenseZipcode = $request->trimValueOf('license_zipcode');		// ライセンス郵便番号
 			$licenseAddress = $request->trimValueOf('license_address');		// ライセンス住所
 			$licenseFax = $request->trimValueOf('license_fax');		// ライセンスFAX
-			//$siteName	= $request->trimValueOf('sitename');		// サイト名称
 			//$siteOwner	= $request->trimValueOf('siteowner');		// サイト所有者
 			//$siteCopyRight	= $request->trimValueOf('sitecopyright');		// サイト著作権
+			$siteName	= $request->trimValueOf('sitename');		// サイト名称
 			$siteEmail	= trim($request->valueOf('siteemail'));		// サイトEメール
 			
 			$siteTitle = $request->trimValueOf('site_title');		// 画面タイトル
+			if (empty($siteTitle)) $siteTitle = $siteName;			// タイトル名が設定されていないときはデフォルトでサイト名称を設定
 			$siteDesc = $request->trimValueOf('site_description');		// サイト要約
 			$siteKeyword = $request->trimValueOf('site_keyword');		// サイトキーワード
 		
@@ -116,6 +117,9 @@ class admin_mainConfigsiteWidgetContainer extends BaseWidgetContainer
 			if (!$isErr){
 				if (!$this->db->updateSiteDef($this->defaultLang, M3_TB_FIELD_SITE_COPYRIGHT, $siteCopyRight)) $isErr = true;
 			}*/
+			if (!$isErr){		// サイト名
+				if (!$this->db->updateSiteDef($this->defaultLang, M3_TB_FIELD_SITE_NAME, $siteName)) $isErr = true;
+			}
 			if (!$isErr){
 				if (!$this->db->updateSiteDef($this->defaultLang, M3_TB_FIELD_SITE_EMAIL, $siteEmail)) $isErr = true;
 			}
@@ -148,9 +152,9 @@ class admin_mainConfigsiteWidgetContainer extends BaseWidgetContainer
 		$this->tmpl->addVar("_widget", "license_address", $this->db->getSiteDef($this->defaultLang, self::LICENSE_ADDRESS));
 		$this->tmpl->addVar("_widget", "license_fax", $this->db->getSiteDef($this->defaultLang, self::LICENSE_FAX));
 		/*
-		$this->tmpl->addVar("_widget", "site_name", $gEnvManager->getSiteName(true));
 		$this->tmpl->addVar("_widget", "site_owner", $gEnvManager->getSiteOwner(true));
 		$this->tmpl->addVar("_widget", "site_copyright", $gEnvManager->getSiteCopyRight(true));*/
+		$this->tmpl->addVar("_widget", "site_name", $gEnvManager->getSiteName(true));		// サイト名
 		$this->tmpl->addVar("_widget", "site_email", $gEnvManager->getSiteEmail(true));
 		// SEO
 		$this->tmpl->addVar("_widget", "site_title", $this->db->getSiteDef($this->defaultLang, M3_TB_FIELD_SITE_TITLE));
