@@ -762,11 +762,11 @@ class bbs_mainThreadDb extends BaseDb
 	 * @param int		$hour				時間
 	 * @return bool							true=成功, false=失敗
 	 */
-	function updateViewCount($thread, $lang, $day, $hour)
+	function updateViewCount($thread, $lang, $day = null, $hour = null)
 	{
 		// 現在日時を取得
-		if (empty($day)) $day = date("Y/m/d");		// 日
-		if (empty($hour)) $hour = (int)date("H");		// 時間
+		if (is_null($day)) $day = date("Y/m/d");		// 日
+		if (is_null($hour)) $hour = (int)date("H");		// 時間
 		
 		// トランザクション開始
 		$this->startTransaction();
