@@ -8,7 +8,7 @@
  *
  * @package    Magic3 Framework
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
- * @copyright  Copyright 2006-2007 Magic3 Project.
+ * @copyright  Copyright 2006-2008 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
  * @version    SVN: $Id$
  * @link       http://www.magic3.org
@@ -45,15 +45,6 @@ class blog_mainWidgetContainer extends BaseWidgetContainer
 		$this->db = new blog_mainDb();
 		$this->sysDb = $gInstanceManager->getSytemDbObject();
 	}
-	/**
-	 * ウィジェット単位のアクセス制御
-	 *
-	 * @param RequestManager $request		HTTPリクエスト処理クラス
-	 */
-	function _checkAccess($request)
-	{
-		return true;
-	}
 	/**
 	 * テンプレートファイルを設定
 	 *
