@@ -8,7 +8,7 @@
  *
  * @package    Magic3 Framework
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
- * @copyright  Copyright 2006-2007 Magic3 Project.
+ * @copyright  Copyright 2006-2008 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
  * @version    SVN: $Id$
  * @link       http://www.magic3.org
@@ -18,7 +18,8 @@ require_once($gEnvManager->getContainerPath() . '/baseWidgetContainer.php');
 class admin_custom_headerWidgetContainer extends BaseWidgetContainer
 {
 	private $db;	// DB接続オブジェクト
-	const IMAGE_DIR = 'images';				// 画像ディレクトリ名
+	const IMAGE_DIR = 'image';				// 画像ディレクトリ名
+	const DEFAULT_IMAGE = 'header9.png';		// デフォルトのヘッダ画像
 	const DEFAULT_BG_COLOR = '#FFCC00';			// バックグランドデフォルトカラー
 	
 	/**
@@ -61,8 +62,17 @@ class admin_custom_headerWidgetContainer extends BaseWidgetContainer
 		if ($act == 'update'){		// 設定更新のとき
 			// 入力値を取得
 			$title	= $request->trimValueOf('item_title');			// ヘッダタイトル
+			$title_mtop = $request->trimValueOf('item_title_mtop');			// ヘッダタイトルマージンtop
+			$title_mleft = $request->trimValueOf('item_title_mleft');			// ヘッダタイトルマージンleft
 			$desc	= $request->trimValueOf('item_desc');	// ヘッダ説明
+			$desc_mtop = $request->trimValueOf('item_desc_mtop');			// ヘッダ説明マージンtop
+			$desc_mleft = $request->trimValueOf('item_desc_mleft');			// ヘッダ説明マージンleft
 			$url	= $request->trimValueOf('item_url');	// ヘッダURL
+			$url_mtop = $request->trimValueOf('item_url_mtop');			// ヘッダURLマージンtop
+			$url_mright = $request->trimValueOf('item_url_mright');			// ヘッダURLマージンright
+			$titleColor = $request->trimValueOf('item_title_color');		// ヘッダタイトルカラー
+			$descColor = $request->trimValueOf('item_desc_color');		// ヘッダ説明カラー
+			$urlColor = $request->trimValueOf('item_url_color');		// ヘッダURLカラー
 			$bgcolor = $request->trimValueOf('item_bgcolor');		// ヘッダバックグランドカラー
 			$width	= $request->trimValueOf('item_width');		// ヘッダの幅
 			$height	= $request->trimValueOf('item_height');		// ヘッダの高さ
@@ -91,10 +101,25 @@ class admin_custom_headerWidgetContainer extends BaseWidgetContainer
 			$this->checkNumeric($titleFontsize, 'タイトルのフォントサイズ');
 			$this->checkNumeric($descFontsize, '説明のフォントサイズ');
 			$this->checkNumeric($urlFontsize, 'URLのフォントサイズ');
+			$this->checkNumeric($title_mtop, 'タイトルマージンtop', true);
+			$this->checkNumeric($title_mleft, 'タイトルマージンleft', true);
+			$this->checkNumeric($desc_mtop, '説明マージンtop', true);
+			$this->checkNumeric($desc_mleft, '説明マージンleft', true);
+			$this->checkNumeric($url_mtop, 'URLマージンtop', true);
+			$this->checkNumeric($url_mright, 'URLマージンright', true);
 			if ($this->getMsgCount() == 0){			// エラーのないとき
 				$paramObj->title	= $title;			// ヘッダタイトル
 				$paramObj->desc		= $desc;		// ヘッダ説明
 				$paramObj->url		= $url;	// ヘッダURL
+				$paramObj->title_mtop = $title_mtop;			// ヘッダタイトルマージンtop
+				$paramObj->title_mleft = $title_mleft;			// ヘッダタイトルマージンleft
+				$paramObj->desc_mtop = $desc_mtop;			// ヘッダ説明マージンtop
+				$paramObj->desc_mleft = $desc_mleft;			// ヘッダ説明マージンleft
+				$paramObj->url_mtop = $url_mtop;			// ヘッダURLマージンtop
+				$paramObj->url_mright = $url_mright;			// ヘッダURLマージンright
+				$paramObj->titleColor = $titleColor;		// ヘッダタイトルカラー
+				$paramObj->descColor = $descColor;		// ヘッダ説明カラー
+				$paramObj->urlColor = $urlColor;		// ヘッダURLカラー
 				$paramObj->bgcolor	= $bgcolor;	// ヘッダバックグランドカラー
 				$paramObj->width	= $width;		// ヘッダの幅
 				$paramObj->height	= $height;		// ヘッダの高さ
@@ -117,7 +142,16 @@ class admin_custom_headerWidgetContainer extends BaseWidgetContainer
 			$title = 'title';	// ヘッダタイトル
 			$desc = 'description';	// ヘッダ説明
 			$url = 'http://www.sample.com';	// ヘッダURL
-			$bgcolor = self::DEFAULT_BG_COLOR;					// ヘッダバックグランドカラー
+			$title_mtop = 10;			// ヘッダタイトルマージンtop
+			$title_mleft = 20;			// ヘッダタイトルマージンleft
+			$desc_mtop = 10;			// ヘッダ説明マージンtop
+			$desc_mleft = 30;			// ヘッダ説明マージンleft
+			$url_mtop = 10;			// ヘッダURLマージンtop
+			$url_mright = 20;			// ヘッダURLマージンright
+			$titleColor = '#FFFFFF';		// ヘッダタイトルカラー
+			$descColor = '#FFFFFF';		// ヘッダ説明カラー
+			$urlColor = '#FFFFFF';		// ヘッダURLカラー
+			$bgcolor = '';					// ヘッダバックグランドカラー
 			$width	= 100;		// ヘッダの幅
 			$height	= 100;		// ヘッダの高さ
 			$widthType = 0;		// ヘッダの幅単位
@@ -126,13 +160,23 @@ class admin_custom_headerWidgetContainer extends BaseWidgetContainer
 			$descFontsize	= 14;// 説明のフォントサイズ
 			$urlFontsize	= 18;	// URLのフォントサイズ
 			$useOriginalImage = 0;			// オリジナル画像を使用するかどうか
-			$imageUrl = '';							// 画像へのパス
+			//$imageUrl = '';							// 画像へのパス
+			$imageUrl = $gEnvManager->getCurrentWidgetRootUrl() . '/' . self::IMAGE_DIR . '/' . self::DEFAULT_IMAGE;// 画像へのパス
 					
 			$paramObj = $this->getWidgetParamObj();
 			if (!empty($paramObj)){
 				$title	= $paramObj->title;			// ヘッダタイトル
 				$desc	= $paramObj->desc;	// ヘッダ説明
 				$url	= $paramObj->url;	// ヘッダURL
+				$title_mtop = $paramObj->title_mtop;			// ヘッダタイトルマージンtop
+				$title_mleft = $paramObj->title_mleft;			// ヘッダタイトルマージンleft
+				$desc_mtop = $paramObj->desc_mtop;			// ヘッダ説明マージンtop
+				$desc_mleft = $paramObj->desc_mleft;			// ヘッダ説明マージンleft
+				$url_mtop = $paramObj->url_mtop;			// ヘッダURLマージンtop
+				$url_mright = $paramObj->url_mright;			// ヘッダURLマージンright
+				$titleColor = $paramObj->titleColor;		// ヘッダタイトルカラー
+				$descColor = $paramObj->descColor;		// ヘッダ説明カラー
+				$urlColor = $paramObj->urlColor;		// ヘッダURLカラー
 				$bgcolor = $paramObj->bgcolor;		// ヘッダバックグランドカラー
 				$width	= $paramObj->width;		// ヘッダの幅
 				$height	= $paramObj->height;		// ヘッダの高さ
@@ -150,6 +194,15 @@ class admin_custom_headerWidgetContainer extends BaseWidgetContainer
 		$this->tmpl->addVar("_widget", "title",	$title);
 		$this->tmpl->addVar("_widget", "desc",	$desc);
 		$this->tmpl->addVar("_widget", "url",	$url);
+		$this->tmpl->addVar("_widget", "title_mtop",	$title_mtop);
+		$this->tmpl->addVar("_widget", "title_mleft",	$title_mleft);
+		$this->tmpl->addVar("_widget", "desc_mtop",	$desc_mtop);
+		$this->tmpl->addVar("_widget", "desc_mleft",	$desc_mleft);
+		$this->tmpl->addVar("_widget", "url_mtop",	$url_mtop);
+		$this->tmpl->addVar("_widget", "url_mright",	$url_mright);
+		$this->tmpl->addVar("_widget", "title_color", $titleColor);
+		$this->tmpl->addVar("_widget", "desc_color", $descColor);
+		$this->tmpl->addVar("_widget", "url_color", $urlColor);
 		$this->tmpl->addVar("_widget", "bgcolor", $bgcolor);
 		$this->tmpl->addVar("_widget", "width",	$width);
 		$this->tmpl->addVar("_widget", "height",	$height);
@@ -206,13 +259,66 @@ class admin_custom_headerWidgetContainer extends BaseWidgetContainer
 			}
 			$dir->close();
 		}
-		// プレビューイメージの設定
-		//$preview = $gEnvManager->getCurrentWidgetRootUrl() . '/' . self::IMAGE_DIR . '/' . $filename;
-		//$this->tmpl->addVar("_widget", "preview_img", $preview);
-		
 		// パスの設定
 		$this->tmpl->addVar("_widget", "widget_url", $gEnvManager->getCurrentWidgetRootUrl());	// ウィジェットのルートディレクトリ
 		$this->tmpl->addVar("_widget", "root_url", $gEnvManager->getRootUrl());
+		
+		// プレビューヘッダの作成
+		// 高さ、幅の単位
+		if (empty($widthType)){		// ヘッダの幅単位
+			$width .= '%';
+		} else {
+			$width .= 'px';
+		}
+		if (empty($heightType)){		// ヘッダの高さ単位
+			$height .= '%';
+		} else {
+			$height .= 'px';
+		}
+		if (empty($imageUrl)){		// 画像を設定しないとき
+			$width = 'width: ' . $width . ';';
+			$height = 'height: ' . $height . ';';			
+		} else {
+			$image = '<img src="' . $imageUrl . '" width="' . $width . '" height="' . $height . '" style="z-index:0" />';
+			$this->tmpl->addVar("_widget", "head_image", $image);		// 画像
+			
+			// CSSの高さ、幅をクリア
+			$width = '';
+			$height = '';
+		}
+		// フォントカラー
+		if (!empty($titleColor)) $titleColor = "color: $titleColor;";		// ヘッダタイトルカラー
+		if (!empty($descColor)) $descColor = "color: $descColor;";			// ヘッダ説明カラー
+		if (!empty($urlColor)) $urlColor = "color: $urlColor;";				// ヘッダURLカラー
+				
+		// 背景色
+		if (!empty($bgcolor)) $bgcolor = "background: $bgcolor;";
+		// 表示文字列の位置
+		if (!empty($title_mtop)) $title_mtop = 'margin-top: ' . $title_mtop . 'px;';
+		if (!empty($title_mleft)) $title_mleft = 'margin-left: ' . $title_mleft . 'px;';
+		if (!empty($desc_mtop)) $desc_mtop = 'margin-top: ' . $desc_mtop . 'px;';
+		if (!empty($desc_mleft)) $desc_mleft = 'margin-left: ' . $desc_mleft . 'px;';
+		if (!empty($url_mtop)) $url_mtop = 'margin-top: ' . $url_mtop . 'px;';
+		if (!empty($url_mright)) $url_mright = 'margin-right: ' . $url_mright . 'px;';
+
+		$this->tmpl->addVar("_widget", "head_title",	$title);
+		$this->tmpl->addVar("_widget", "head_desc",	$desc);
+		$this->tmpl->addVar("_widget", "head_url",	$url);
+		$this->tmpl->addVar("_widget", "head_title_mtop",	$title_mtop);
+		$this->tmpl->addVar("_widget", "head_title_mleft",	$title_mleft);
+		$this->tmpl->addVar("_widget", "head_desc_mtop",	$desc_mtop);
+		$this->tmpl->addVar("_widget", "head_desc_mleft",	$desc_mleft);
+		$this->tmpl->addVar("_widget", "head_url_mtop",	$url_mtop);
+		$this->tmpl->addVar("_widget", "head_url_mright",	$url_mright);
+		$this->tmpl->addVar("_widget", "head_title_color", $titleColor);
+		$this->tmpl->addVar("_widget", "head_desc_color", $descColor);
+		$this->tmpl->addVar("_widget", "head_url_color", $urlColor);
+		$this->tmpl->addVar("_widget", "head_bgcolor", $bgcolor);
+		$this->tmpl->addVar("_widget", "head_width",	$width);
+		$this->tmpl->addVar("_widget", "head_height",	$height);
+		$this->tmpl->addVar("_widget", "head_title_fontsize",	$titleFontsize);
+		$this->tmpl->addVar("_widget", "head_desc_fontsize",	$descFontsize);
+		$this->tmpl->addVar("_widget", "head_url_fontsize",	$urlFontsize);
 	}
 }
 ?>
