@@ -92,6 +92,10 @@ class admin_ec_mainBaseWidgetContainer extends BaseWidgetContainer
 			case 'delivmethod_detail':		// 配送方法(詳細)
 				$linkList = ' &gt;&gt; 基本設定 &gt;&gt; 配送方法';// パンくずリスト
 				break;
+			case 'customer':	// 取引先管理
+			case 'customer_detail':	// 取引先管理(詳細)
+				$linkList = ' &gt;&gt; 基本設定 &gt;&gt; 取引先';// パンくずリスト
+				break;
 			case 'keyword':		// 文字列変換設定
 			case 'keyword_detail':		// 文字列変換設定(詳細)
 				$linkList = ' &gt;&gt; 基本設定 &gt;&gt; 置換文字列編集';// パンくずリスト
@@ -175,6 +179,8 @@ class admin_ec_mainBaseWidgetContainer extends BaseWidgetContainer
 			$task == 'paymethod_detail' ||		// 支払方法(詳細)
 			$task == 'delivmethod' ||		// 配送方法
 			$task == 'delivmethod_detail' ||		// 配送方法(詳細)
+			$task == 'customer' ||		// 取引先
+			$task == 'customer_detail' ||		// 取引先(詳細)
 			$task == 'keyword' ||		// 文字列変換設定
 			$task == 'keyword_detail' ||		// 文字列変換設定(詳細)
 			$task == 'other'){		// その他設定
@@ -275,6 +281,8 @@ class admin_ec_mainBaseWidgetContainer extends BaseWidgetContainer
 			$task == 'paymethod_detail' ||		// 支払方法(詳細)
 			$task == 'delivmethod' ||		// 配送方法
 			$task == 'delivmethod_detail' ||		// 配送方法(詳細)
+			$task == 'customer' ||		// 取引先
+			$task == 'customer_detail' ||		// 取引先(詳細)
 			$task == 'keyword' ||		// 文字列変換設定
 			$task == 'keyword_detail' ||		// 文字列変換設定(詳細)
 			$task == 'other'){		// その他
@@ -306,6 +314,13 @@ class admin_ec_mainBaseWidgetContainer extends BaseWidgetContainer
 					'&' . M3_REQUEST_PARAM_WIDGET_ID . '=' . $gEnvManager->getCurrentWidgetId() . '&task=paymethod';
 			if ($task == 'paymethod' || $task == 'paymethod_detail') $current = 'id="current"';
 			$menuText .= '<li ' . $current . '><a href="'. $link .'"><span>支払方法</span></a></li>' . M3_NL;
+			
+			// 取引先
+			$current = '';
+			$link = $gEnvManager->getDefaultAdminUrl() . '?' . M3_REQUEST_PARAM_OPERATION_COMMAND . '=' . M3_REQUEST_CMD_CONFIG_WIDGET . 
+					'&' . M3_REQUEST_PARAM_WIDGET_ID . '=' . $gEnvManager->getCurrentWidgetId() . '&task=customer';
+			if ($task == 'customer' || $task == 'customer_detail') $current = 'id="current"';
+			$menuText .= '<li ' . $current . '><a href="'. $link .'"><span>取引先</span></a></li>' . M3_NL;
 		
 			// メール連携
 			$current = '';
