@@ -195,6 +195,8 @@ class admin_ec_mainProductlistWidgetContainer extends admin_ec_mainBaseWidgetCon
 				$visible = 'checked';
 			}
 		}
+		$stockCount = $fetchedRow['pe_stock_count'];// 表示在庫数
+		if (empty($stockCount)) $stockCount = 0;
 		
 		$row = array(
 			'line_color' => $lineColor,											// 行のカラー
@@ -204,7 +206,7 @@ class admin_ec_mainProductlistWidgetContainer extends admin_ec_mainBaseWidgetCon
 			'name' => $this->convertToDispString($row['pt_name']),		// 名前
 			'code' => $this->convertToDispString($row['pt_code']),		// 商品コード
 			'price' => $dispPrice,													// 価格(税込)
-			'stock_count' => $this->convertToDispString($row['pt_view_stock_count']),		// 表示在庫数
+			'stock_count' => $stockCount,		// 表示在庫数
 			'view_index' => $this->convertToDispString($row['pt_sort_order']),		// 表示順
 			'lang' => $lang,													// 対応言語
 			'update_user' => $this->convertToDispString($row['lu_name']),	// 更新者
