@@ -77,7 +77,12 @@ class admin_ec_mainWidgetContainer extends admin_ec_mainBaseWidgetContainer
 			case 'category_detail':	// 商品カテゴリ管理(詳細)
 				$task = 'category';
 				$goWidget = true;		// サブウィジェットを実行するかどうか
-				break;			
+				break;
+			case 'customer':	// 取引先管理
+			case 'customer_detail':	// 取引先管理(詳細)
+				$task = 'customer';
+				$goWidget = true;		// サブウィジェットを実行するかどうか
+				break;
 			case 'keyword':		// 置換文字列設定
 			case 'keyword_detail':		// 置換文字列設定(詳細)
 				$task = 'keyword';
