@@ -15,10 +15,12 @@
  */
 require_once($gEnvManager->getContainerPath()		. '/baseWidgetContainer.php');
 require_once($gEnvManager->getCurrentWidgetDbPath()	. '/ec_mainCartDb.php');
+require_once($gEnvManager->getCurrentWidgetDbPath() .	'/productDb.php');
 
 class ec_mainCartWidgetContainer extends BaseWidgetContainer
 {
 	private $db;			// DB接続オブジェクト
+	private $productDb;	// DB接続オブジェクト
 	private $langId;		// 現在の言語
 	private $ecObj;					// EC共通ライブラリオブジェクト
 	private $productExists;			// カートに商品があるかどうか
@@ -39,6 +41,7 @@ class ec_mainCartWidgetContainer extends BaseWidgetContainer
 		
 		// DBオブジェクト作成
 		$this->db = new ec_mainCartDb();
+		$this->productDb = new productDb();
 		
 		// EC用共通オブジェクト取得
 		$this->ecObj = $gInstanceManager->getObject(self::PRICE_OBJ_ID);
@@ -176,7 +179,7 @@ class ec_mainCartWidgetContainer extends BaseWidgetContainer
 		$id = $fetchedRow['si_product_id'];	// 商品ID
 		
 		// 商品を取得
-		$ret = $this->db->getProductByProductId($id, $this->langId, $row, $row2, $row3, $row4, $row5);
+		$ret = $this->productDb->getProductByProductId($id, $this->langId, $row, $row2, $row3, $row4, $row5);
 		if ($ret){
 			$name = $this->convertToDispString($row['pt_name']);		// 名前
 			$code = $this->convertToDispString($row['pt_code']);		// 商品コード
@@ -271,7 +274,7 @@ class ec_mainCartWidgetContainer extends BaseWidgetContainer
 		$priceStatus = 1;	// 価格が有効であるかどうか
 		
 		// 商品を取得
-		$ret = $this->db->getProductByProductId($id, $this->langId, $row, $row2, $row3, $row4, $row5);
+		$ret = $this->productDb->getProductByProductId($id, $this->langId, $row, $row2, $row3, $row4, $row5);
 		if ($ret){
 			$name = $this->convertToDispString($row['pt_name']);		// 名前
 			$code = $this->convertToDispString($row['pt_code']);		// 商品コード
