@@ -17,12 +17,14 @@ require_once($gEnvManager->getContainerPath() . '/baseWidgetContainer.php');
 require_once($gEnvManager->getCurrentWidgetDbPath()	. '/ec_mainOrderDb.php');
 require_once($gEnvManager->getCurrentWidgetDbPath()	. '/ec_mainCartDb.php');
 require_once($gEnvManager->getCurrentWidgetDbPath() .	'/ec_mainDb.php');
+require_once($gEnvManager->getCurrentWidgetDbPath() .	'/productDb.php');
 
 class ec_mainConfirmWidgetContainer extends BaseWidgetContainer
 {
 	private $db;	// DB接続オブジェクト
 	private $cartDb;		// カートアクセス用ＤＢオブジェクト
 	private $mainDb;
+	private $productDb;	// DB接続オブジェクト
 	private $deliveryMethod;		// 配送方法
 	private $payMethod;			// 支払い方法
 	private $orderId;			// 受注ID
@@ -55,6 +57,7 @@ class ec_mainConfirmWidgetContainer extends BaseWidgetContainer
 		$this->db = new ec_mainOrderDb();
 		$this->cartDb = new ec_mainCartDb();
 		$this->mainDb = new ec_mainDb();
+		$this->productDb = new productDb();
 		
 		// 価格計算用オブジェクト取得
 		$this->ecObj = $gInstanceManager->getObject(self::PRICE_OBJ_ID);
@@ -347,7 +350,7 @@ class ec_mainConfirmWidgetContainer extends BaseWidgetContainer
 		$id = $fetchedRow['si_product_id'];	// 商品ID
 		
 		// 商品を取得
-		$ret = $this->cartDb->getProductByProductId($id, $this->langId, $row, $row2, $row3, $row4, $row5);
+		$ret = $this->productDb->getProductByProductId($id, $this->langId, $row, $row2, $row3, $row4, $row5);
 		if ($ret){
 			$name = $this->convertToDispString($row['pt_name']);		// 名前
 			$code = $this->convertToDispString($row['pt_code']);		// 商品コード
@@ -444,7 +447,7 @@ class ec_mainConfirmWidgetContainer extends BaseWidgetContainer
 		$subtotal = $fetchedRow['si_subtotal'];
 		
 		// 商品を取得
-		$ret = $this->cartDb->getProductByProductId($id, $this->langId, $row, $row2, $row3, $row4, $row5);
+		$ret = $this->productDb->getProductByProductId($id, $this->langId, $row, $row2, $row3, $row4, $row5);
 		if ($ret){
 			$name = $this->convertToDispString($row['pt_name']);		// 名前
 			$code = $this->convertToDispString($row['pt_code']);		// 商品コード
@@ -464,6 +467,20 @@ class ec_mainConfirmWidgetContainer extends BaseWidgetContainer
 			// 受注明細を登録
 			$tax = $subtotal - $price * $quantity;
 			$this->db->addOrderDetail($this->orderId, $index, $id, $name, $price, $quantity, $tax, $subtotal, $this->userId, $this->now);
+			
+			// 表示在庫数、累積注文数を更新
+			$stockCount = $row['pe_stock_count'];
+			if (empty($stockCount)) $stockCount = 0;
+			$stockCount -= $quantity;
+			if ($stockCount < 0) $stockCount = 0;
+			$orderCount = $row['pe_sales_count'];
+			if (empty($orderCount)) $orderCount = 0;
+			$orderCount += $quantity;
+			
+			$updateParam = array();
+			$updateParam['pe_stock_count'] = $stockCount;
+			$updateParam['pe_order_count'] = $orderCount;
+			$this->productDb->updateProductRecord($id, $this->langId, $updateParam);
 		}
 		return true;
 	}
