@@ -42,6 +42,7 @@ class ec_mainProductWidgetContainer extends BaseWidgetContainer
 	const DEFAULT_TAX_TYPE = 'sales';			// デフォルト税種別
 	const VIEW_STYLE_SMALL = 'small';			// 表示スタイル(小)
 	const VIEW_STYLE_MEDIUM = 'medium';			// 表示スタイル(中)
+	const VIEW_STYLE_LARGE = 'large';			// 表示スタイル(大)
 	const DEFAULT_LIST_COUNT = 5;			// 最大リスト表示数
 	const DISP_PRODUCT_COUNT	= 'disp_product_count';		// 商品一覧の商品表示数
 	
@@ -344,6 +345,9 @@ class ec_mainProductWidgetContainer extends BaseWidgetContainer
 				$this->tmpl->addVar("show_productlist", "title", '商品一覧');
 			}
 		} else {		// 商品詳細表示のとき
+			// 表示モードは画像大
+			$this->viewStyle = self::VIEW_STYLE_LARGE;
+			
 			$ret = $this->db->getProductByProductId($this->productId, $currentLang, $row, $row2, $row3, $row4, $row5);
 			if ($ret){
 				// 取得値を設定
@@ -417,7 +421,7 @@ class ec_mainProductWidgetContainer extends BaseWidgetContainer
 				}
 				// 画像大
 				$destImg_l = '';
-				if ($this->viewStyle == self::VIEW_STYLE_MEDIUM){
+				if ($this->viewStyle == self::VIEW_STYLE_LARGE){
 					$imageUrl_l = $this->getProperImage($images, 2);
 					if (empty($imageUrl_l)){
 						$destImg_l = '<img id="preview_img_large" style="display:none;" ';
@@ -589,7 +593,7 @@ class ec_mainProductWidgetContainer extends BaseWidgetContainer
 		}
 		// 画像大
 		$destImg_l = '';
-		if ($this->viewStyle == self::VIEW_STYLE_MEDIUM){
+		if ($this->viewStyle == self::VIEW_STYLE_LARGE){
 			$imageUrl_l = $this->getProperImage($images, 2);
 			if (empty($imageUrl_l)){		// 画像が空のとき
 				$destImg_l = '<img id="preview_img_large" style="display:none;" ';
