@@ -279,7 +279,7 @@ class ec_mainMemberDb extends BaseDb
 		} else {
 			$userType = UserInfo::USER_TYPE_NORMAL;		// 一般ユーザ
 		}
-		$subject = 'ec,';		// EC機能(ec)にアクセス可能
+		$subject = '2,';		// EC機能(2)にアクセス可能
 		
 		// 新規レコードを追加
 		$queryStr  = 'INSERT INTO _login_user (';
