@@ -182,7 +182,8 @@ class productDb extends BaseDb
 	 */
 	function getProductBySerial($serial, &$row, &$row2, &$row3, &$row4, &$row5)
 	{
-		$queryStr  = 'select * from product LEFT JOIN _login_user ON pt_create_user_id = lu_id AND lu_deleted = false ';
+		$queryStr  = 'select * from (product LEFT JOIN product_record ON pt_id = pe_product_id AND pt_language_id = pe_language_id) ';
+		$queryStr .=   'LEFT JOIN _login_user ON pt_create_user_id = lu_id AND lu_deleted = false ';
 		$queryStr .=   'WHERE pt_serial = ? ';
 		$ret = $this->selectRecord($queryStr, array($serial), $row);
 		if ($ret){
@@ -230,7 +231,9 @@ class productDb extends BaseDb
 	 */
 	function getProductByProductId($id, $langId, &$row, &$row2, &$row3, &$row4, &$row5)
 	{
-		$queryStr  = 'SELECT * FROM product LEFT JOIN _login_user ON pt_create_user_id = lu_id AND lu_deleted = false ';
+		//$queryStr  = 'SELECT * FROM product LEFT JOIN _login_user ON pt_create_user_id = lu_id AND lu_deleted = false ';
+		$queryStr  = 'select * from (product LEFT JOIN product_record ON pt_id = pe_product_id AND pt_language_id = pe_language_id) ';
+		$queryStr .=   'LEFT JOIN _login_user ON pt_create_user_id = lu_id AND lu_deleted = false ';
 		$queryStr .=   'WHERE pt_deleted = false ';	// 削除されていない
 		$queryStr .=   'AND pt_id = ? ';
 		$queryStr .=   'AND pt_language_id = ? ';
@@ -396,7 +399,28 @@ class productDb extends BaseDb
 		$queryStr = 'select max(pt_serial) as ns from product ';
 		$ret = $this->selectRecord($queryStr, array(), $row);
 		if ($ret) $newSerial = $row['ns'];
-			
+		
+		// 表示在庫数更新
+		$queryStr = 'SELECT * FROM product_record ';
+		$queryStr .=  'WHERE pe_product_id = ? ';
+		$queryStr .=    'AND pe_language_id = ? ';
+		$ret = $this->selectRecord($queryStr, array($pId, $lang), $stockRow);
+		if ($ret){	// データが存在するとき
+			// データを更新
+			$queryStr  = 'UPDATE product_record ';
+			$queryStr .=   'SET pe_stock_count = ?, ';
+			$queryStr .=     'pe_update_user_id = ?, ';
+			$queryStr .=     'pe_update_dt = ? ';
+			$queryStr .=   'WHERE pe_serial = ?';
+			$this->execStatement($queryStr, array($stockCount, $userId, $now, $stockRow['pe_serial']));
+		} else {
+			$queryStr = 'INSERT INTO product_record ';
+			$queryStr .=  '(pe_product_id, pe_language_id, pe_stock_count, pe_update_user_id, pe_update_dt) ';
+			$queryStr .=  'VALUES ';
+			$queryStr .=  '(?, ?, ?, ?, ?)';
+			$this->execStatement($queryStr, array($pId, $lang, $stockCount, $userId, $now));
+		}
+		
 		// 価格の更新
 		for ($i = 0; $i < count($prices); $i++){
 			$price = $prices[$i];
@@ -511,12 +535,33 @@ class productDb extends BaseDb
 		$this->execStatement($queryStr, array($row['pt_id'], $row['pt_language_id'], $historyIndex,
 							$name, $code, $row['pt_product_type'], $category, $index, $visible, $unitType, $unitQuantity, $description, 
 							$description_short, $keyword, $url, $taxType, $adminNote, $userId, $now));
-
+		
 		// 新規のシリアル番号取得
 		$queryStr = 'select max(pt_serial) as ns from product ';
 		$ret = $this->selectRecord($queryStr, array(), $row);
 		if ($ret) $newSerial = $row['ns'];
 		
+		// 表示在庫数更新
+		$queryStr = 'SELECT * FROM product_record ';
+		$queryStr .=  'WHERE pe_product_id = ? ';
+		$queryStr .=    'AND pe_language_id = ? ';
+		$ret = $this->selectRecord($queryStr, array($pId, $lang), $stockRow);
+		if ($ret){	// データが存在するとき
+			// データを更新
+			$queryStr  = 'UPDATE product_record ';
+			$queryStr .=   'SET pe_stock_count = ?, ';
+			$queryStr .=     'pe_update_user_id = ?, ';
+			$queryStr .=     'pe_update_dt = ? ';
+			$queryStr .=   'WHERE pe_serial = ?';
+			$this->execStatement($queryStr, array($stockCount, $userId, $now, $stockRow['pe_serial']));
+		} else {
+			$queryStr = 'INSERT INTO product_record ';
+			$queryStr .=  '(pe_product_id, pe_language_id, pe_stock_count, pe_update_user_id, pe_update_dt) ';
+			$queryStr .=  'VALUES ';
+			$queryStr .=  '(?, ?, ?, ?, ?)';
+			$this->execStatement($queryStr, array($pId, $lang, $stockCount, $userId, $now));
+		}
+		
 		// 価格の更新
 		for ($i = 0; $i < count($prices); $i++){
 			$price = $prices[$i];
@@ -1072,7 +1117,7 @@ class productDb extends BaseDb
 		}
 		$serialStr = implode(',', $serialArray);
 
-		$queryStr = 'SELECT * FROM product ';
+		$queryStr = 'SELECT * FROM product LEFT JOIN product_record ON pt_id = pe_product_id AND pt_language_id = pe_language_id ';
 		if (!empty($serialStr)) $queryStr .=  'WHERE pt_serial in (' . $serialStr . ') ';
 		$queryStr .=  'ORDER BY pt_sort_order limit ' . $limit . ' offset ' . $offset;
 		$this->selectLoop($queryStr, array(), $callback, null);
@@ -1112,5 +1157,70 @@ class productDb extends BaseDb
 		}
 		return $this->selectRecordCount($queryStr, $params);
 	}
+	/**
+	 * 商品記録を更新
+	 *
+	 * @param int	  $id			商品ID
+	 * @param string  $lang			言語ID
+	 * @param array	$updateParam	更新パラメータ
+	 * @return bool					true = 成功、false = 失敗
+	 */
+	function updateProductRecord($id, $lang, $updateParam)
+	{
+		global $gEnvManager;
+		
+		$now = date("Y/m/d H:i:s");	// 現在日時
+		$userId = $gEnvManager->getCurrentUserId();	// 現在のユーザ
+		
+		// パラメータエラーチェック
+		$keys = array_keys($updateParam);
+		if (in_array('pe_serial', $keys)) return false;
+				
+		// 既存データ取得
+		$queryStr = 'SELECT * FROM product_record ';
+		$queryStr .=  'WHERE pe_product_id = ? ';
+		$queryStr .=    'AND pe_language_id = ? ';
+		$ret = $this->selectRecord($queryStr, array($id, $lang), $stockRow);
+		if ($ret){	// データが存在するとき
+			// ##### データを更新 #####
+			// レコード更新
+			$queryStr = 'UPDATE product_record ';
+			$queryStr .=  'SET ';
+			$values = array();
+			for ($i = 0; $i < count($keys); $i++){
+				$queryStr .= $keys[$i] . ' = ?, ';
+				$values[] = $updateParam[$keys[$i]];
+			}
+			$queryStr .= 'pe_update_user_id = ?, '; $values[] = $userId;
+			$queryStr .= 'pe_update_dt = ? '; $values[] = $now;
+			$queryStr .=  'WHERE pe_serial = ? ';
+			$values[] = $stockRow['pe_serial'];
+			$ret =$this->execStatement($queryStr, $values);
+		} else {
+			// ##### データを新規追加 #####
+			// 新規レコード追加
+			$queryStr = 'INSERT INTO product_record ';
+			$queryStr .=  '(';
+		
+			$valueStr = '(';
+			$values = array();
+			for ($i = 0; $i < count($keys); $i++){
+				$queryStr .= $keys[$i] . ', ';
+				$valueStr .= '?, ';
+				$values[] = $updateParam[$keys[$i]];
+			}
+			$queryStr .= 'pe_product_id, pe_language_id, pe_update_user_id, pe_update_dt) ';
+			$valueStr .= '?, ?, ?, ?) ';
+			$values[] = $id;
+			$values[] = $lang;
+			$values[] = $userId;
+			$values[] = $now;
+			
+			$queryStr .=  'VALUES ';
+			$queryStr .=  $valueStr;
+			$ret =$this->execStatement($queryStr, $values);
+		}
+		return $ret;
+	}
 }
 ?>
