@@ -301,21 +301,5 @@ class admin_reserve_mainResourceWidgetContainer extends admin_reserve_mainBaseWi
 		$this->serialArray[] = $serial;
 		return true;
 	}
-	/**
-	 * ユーザの削除、ログインアカウントも削除
-	 *
-	 * @param int $serial		シリアル番号
-	 * @return bool				true=成功、false=失敗
-	 */
-	function deleteUser($serial)
-	{
-		$ret = $this->db->delMemberBySerial(1, $serial);
-
-		if ($ret){		// データ削除成功のとき
-			return true;
-		} else {
-			return false;
-		}
-	}
 }
 ?>
